MSprogOutput: Objects of class "MSprogOutput"

MSprogOutputR Documentation

Objects of class "MSprogOutput"

Description

Objects of class "MSprogOutput" are returned by MSprog(). They contain the results of event detection and associated metadata.

Structure

Objects of class "MSprogOutput" are lists with the following elements:

event_count

A data frame containing event counts for each subject (and the event sequence in case of multiple events).

results

A data frame with extended info on each event for all subjects.

settings

A list containing all the arguments used to compute the output.

unconfirmed

A data frame with info on unconfirmed events (initial change from baseline, but no confirmation) for all subjects.

event_count data frame

event_sequence

Sequence of detected events (if any), in chronological order (only displayed in multiple-event setting).

CDI

Count of confirmed disability improvement (CDI) events.

CDW

Count of confirmed disability worsening (CDW) events.

RAW

Count of relapse-associated worsening (RAW) events.

PIRA

Count of progression independent of relapse activity (PIRA) events.

Note: depending on computation settings, some of the above columns may not be included in the data frame (e.g., no CDI column if event="firstCDW" in MSprog()).

results data frame

⁠<subj_col>⁠

Subject ID.

nevent

Cumulative count of events for the subject.

event_type

Type of event (CDI or CDW).

CDW_type

Type of CDW (PIRA, RAW, undefined).

total_fu

Total length of follow-up period in days.

time2event

Number of days from start of follow-up to event onset.

bl2event

Number of days from baseline to event onset.

date

Date of event onset.

value

Outcome value at event onset.

initial_bl_date

Date of initial baseline for the subject (first eligible baseline visit).

initial_bl_value

Outcome value at initial baseline (first eligible baseline visit).

bl_date

Date of baseline for the event.

bl_value

Outcome value at baseline.

last_delta_date

Date of last visit before event onset at a clinically meaningful score distance from it.

last_delta_value

Last outcome value before event onset at a clinically meaningful score distance from it.

conf⁠<conf_days>⁠_date

Date of ⁠<conf_days>⁠-day confirmation visit for the event.

conf⁠<conf_days>⁠_value

Outcome value at ⁠<conf_days>⁠-day confirmation visit.

PIRA_conf⁠<conf_days>⁠_date

When relevant, date of ⁠<conf_days>⁠-day confirmation visit for PIRA (could be different from CDW confirmation visit if the PIRA definition includes confirmation-related constraints on relapses).

PIRA_conf⁠<conf_days>⁠_value

When relevant, outcome value at ⁠<conf_days>⁠-day confirmation visit for PIRA (could be different from CDW confirmation visit if the PIRA definition includes confirmation-related constraints on relapses).

sust_days

Number of days for which the event was sustained.

sust_last

Whether the event was sustained up to the end of follow-up.

Note: some of the columns may not be included, depending on computation settings (e.g., no date columns if include_dates=F in MSprog()).

unconfirmed data frame

⁠<subj_col>⁠

Subject ID.

date

Date of initial outcome change.

value

Outcome value at initial outcome change.

bl_date

Date of baseline.

bl_value

Outcome value at baseline.

closest_rel_before

Distance in days from the last relapse before the outcome change (if any).

closest_rel_after

Distance in days from the next relapse after the outcome change (if any).

Note: in first-event scenarios (e.g., event="firstCDW"), the event search stops as soon as the first confirmed event is found – in this case, the unconfirmed data frame only reports unconfirmed outcome changes occurring before detecting a confirmed event.


msprog documentation built on Sept. 4, 2026, 5:08 p.m.