compute_delta: Default minimum clinically meaningful shift for different...

View source: R/event_testing.R

compute_deltaR Documentation

Default minimum clinically meaningful shift for different scales.

Description

Compute the minimum clinically meaningful score change as a function of the reference value for some widely used scales (EDSS, NHPT, T25FW, or SDMT), according to the most established rule for each of these outcomes.

Usage

compute_delta(baseline, outcome = "edss")

Arguments

baseline

Outcome value at baseline.

outcome

One of:

  • "edss" (Extended Disability Status Scale, default);

  • "nhpt" (Nine-Hole Peg Test);

  • "t25fw" (Timed 25-Foot Walk);

  • "sdmt" (Symbol Digit Modalities Test).

Details

Default thresholds are meant to apply to all versions of each test (e.g., dominant or non-dominant hand for NHPT, best time or mean of two trials, etc.).

Value

Minimum clinically meaningful change from the provided baseline value. Specifically:

  • EDSS: 1.5 if baseline=0, 1 if 0<baseline<=5.0, 0.5 if baseline>5.0

  • NHPT and T25FW: 20⁠%⁠ of baseline

  • SDMT: either 4 points or 20⁠%⁠ of baseline.

Examples

compute_delta(4.5) # default outcome is "edss"
compute_delta(55, outcome="sdmt")

msprog documentation built on Sept. 4, 2026, 5:08 p.m.