print.MSprogOutput: Textual description of criteria used to assess disability...

View source: R/msprog_methods.R

print.MSprogOutputR Documentation

Textual description of criteria used to assess disability course.

Description

print method for class "MSprogOutput".

Usage

## S3 method for class 'MSprogOutput'
print(x, ...)

Arguments

x

An object of class "MSprogOutput" (result of a call to MSprog()).

...

Optional arguments for print methods. They are ignored in this function.

Details

The method prints out (1) the package version, (2) a full list of function arguments, and (3) a short paragraph describing the full set of criteria used to obtain the output.

Value

Invisibly returns x.

Examples

output <- MSprog(toydata_visits, "id", "EDSS", "date", "edss",
    relapse=toydata_relapses, conf_days=7*12, conf_tol_days=30,
    event="multiple", baseline="roving", verbose=2)
print(output) # textual description of parameters used to obtain output

msprog documentation built on Sept. 4, 2026, 5:08 p.m.