toydata_relapses: Synthetic Relapse Data

toydata_relapsesR Documentation

Synthetic Relapse Data

Description

Artificially generated relapse onset dates for some example patients in toydata_visits to illustrate the use of the package.

Usage

data(toydata_relapses)

Format

An object of class data.frame, with columns:

id

Subject IDs.

date

Relapse onset dates.

References

This data set was artificially created for the msprog package.

Examples


data(toydata_relapses)
head(toydata_relapses)


msprog documentation built on Sept. 4, 2026, 5:08 p.m.