toydata_visits: Synthetic Longitudinal EDSS and SDMT Data

toydata_visitsR Documentation

Synthetic Longitudinal EDSS and SDMT Data

Description

Artificially generated toy data set including Extended Disability Status Scale (EDSS) and Symbol Digit Modalities Test (SDMT) scores in a small cohort of example patients to illustrate the use of the package.

Usage

data(toydata_visits)

Format

An object of class data.frame, with columns:

id

Subject IDs.

date

Visit dates.

EDSS

Synthetic EDSS scores (values between 0 and 10).

SDMT

Synthetic SDMT scores (values between 0 and 110).

References

This data set was artificially created for the msprog package.

Examples


head(toydata_visits)


msprog documentation built on Sept. 4, 2026, 5:08 p.m.