| MSprogOutput | R Documentation |
Objects of class "MSprogOutput" are returned by MSprog(). They contain
the results of event detection and associated metadata.
Objects of class "MSprogOutput" are lists with the following elements:
event_countA data frame containing event counts for each subject (and the event sequence in case of multiple events).
resultsA data frame with extended info on each event for all subjects.
settingsA list containing all the arguments used to compute the output.
unconfirmedA data frame with info on unconfirmed events (initial change from baseline, but no confirmation) for all subjects.
event_count data frameSequence of detected events (if any), in chronological order (only displayed in multiple-event setting).
Count of confirmed disability improvement (CDI) events.
Count of confirmed disability worsening (CDW) events.
Count of relapse-associated worsening (RAW) events.
Count of progression independent of relapse activity (PIRA) events.
Note: depending on computation settings, some of the above columns may not be
included in the data frame (e.g., no CDI column if event="firstCDW" in MSprog()).
results data frame<subj_col>Subject ID.
Cumulative count of events for the subject.
Type of event (CDI or CDW).
Type of CDW (PIRA, RAW, undefined).
Total length of follow-up period in days.
Number of days from start of follow-up to event onset.
Number of days from baseline to event onset.
Date of event onset.
Outcome value at event onset.
Date of initial baseline for the subject (first eligible baseline visit).
Outcome value at initial baseline (first eligible baseline visit).
Date of baseline for the event.
Outcome value at baseline.
Date of last visit before event onset at a clinically meaningful score distance from it.
Last outcome value before event onset at a clinically meaningful score distance from it.
<conf_days>_dateDate of <conf_days>-day confirmation visit for the event.
<conf_days>_valueOutcome value at <conf_days>-day confirmation visit.
<conf_days>_dateWhen relevant, date of <conf_days>-day confirmation visit for PIRA
(could be different from CDW confirmation visit if the PIRA definition includes confirmation-related constraints on relapses).
<conf_days>_valueWhen relevant, outcome value at <conf_days>-day confirmation visit for PIRA
(could be different from CDW confirmation visit if the PIRA definition includes confirmation-related constraints on relapses).
Number of days for which the event was sustained.
Whether the event was sustained up to the end of follow-up.
Note: some of the columns may not be included, depending on computation settings
(e.g., no date columns if include_dates=F in MSprog()).
unconfirmed data frame<subj_col>Subject ID.
Date of initial outcome change.
Outcome value at initial outcome change.
Date of baseline.
Outcome value at baseline.
Distance in days from the last relapse before the outcome change (if any).
Distance in days from the next relapse after the outcome change (if any).
Note: in first-event scenarios (e.g., event="firstCDW"), the event search stops as soon as
the first confirmed event is found – in this case, the unconfirmed data frame only reports
unconfirmed outcome changes occurring before detecting a confirmed event.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.