View source: R/event_testing.R
| compute_delta | R Documentation |
Compute the minimum clinically meaningful score change as a function of the reference value for some widely used scales (EDSS, NHPT, T25FW, or SDMT), according to the most established rule for each of these outcomes.
compute_delta(baseline, outcome = "edss")
baseline |
Outcome value at baseline. |
outcome |
One of:
|
Default thresholds are meant to apply to all versions of each test (e.g., dominant or non-dominant hand for NHPT, best time or mean of two trials, etc.).
Minimum clinically meaningful change from the provided baseline value. Specifically:
EDSS: 1.5 if baseline=0, 1 if 0<baseline<=5.0, 0.5 if baseline>5.0
NHPT and T25FW: 20% of baseline
SDMT: either 4 points or 20% of baseline.
compute_delta(4.5) # default outcome is "edss"
compute_delta(55, outcome="sdmt")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.