View source: R/event_testing.R
| is_event | R Documentation |
Check if an outcome value determines a valid worsening, or improvement, or change, from a given reference value.
is_event(
x,
baseline,
type,
outcome = "edss",
worsening = NULL,
delta_fun = NULL,
sub_threshold = FALSE
)
x |
Outcome value to test. |
baseline |
Outcome value at baseline. |
type |
One of:
|
outcome |
One of:
Outcome type determines the direction of worsening (see |
worsening |
The direction of worsening ( |
delta_fun |
Custom function specifying the minimum clinically meaningful
change in the outcome measure from the provided reference value.
The function provided must take a numeric value (reference score) as input,
and return a numeric value corresponding to the minimum relevant shift from baseline, see example below.
If |
sub_threshold |
If |
A boolean value specifying if a valid event was found.
is_event(x=4.5, baseline=4, type="wors", outcome="edss")
is_event(x=50, baseline=57, type="wors", outcome="sdmt")
is_event(x=3, baseline=3.5, type="impr", outcome="edss", sub_threshold=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.