View source: R/relapse_indep_from_bounds.R
| relapse_indep_from_bounds | R Documentation |
Organise the given interval bounds into a named list to be given as argument
relapse_indep to function MSprog().
The relapse-free intervals may be anchored to (any subset of) the following
three data-driven checkpoints.
"prec": a visit preceding the event: can be (i) the current baseline, (ii) the last visit before event onset,
or (iii) the last visit before event onset with a clinically meaningful score difference from it
(i.e., for an outcome x with "higher score" = "worse", the last visit i such that x[event] - x[i] >= delta_fun(x[i]),
and same for the confirmation visit).
"event": the disability worsening event onset.
"conf": an eligible confirmation visit.
relapse_indep_from_bounds(
p0 = 0,
p1 = 0,
e0 = 0,
e1 = 0,
c0 = 0,
c1 = 0,
prec_type = "baseline",
use_end_dates = FALSE
)
p0 |
Days before preceding visit ( |
p1 |
Days after preceding visit ( |
e0 |
Days before event onset ( |
e1 |
Days after event onset ( |
c0 |
Days before confirmation ( |
c1 |
Days after confirmation ( |
prec_type |
Which visit to use as "preceding visit". Must be one of:
|
use_end_dates |
If |
If both ends of an interval are 0 (e.g., if both p0=0 and p1=0), the checkpoint is ignored.
To merge two intervals together, set both the right end of the first interval and the left end of the
second interval to NULL (e.g., "between baseline and event onset": p1=NULL and e0=NULL).
Here are some examples:
No relapses from 90dd before to 30dd after the event, and from 90dd before to 30dd after confirmation [1]:
relapse_indep_from_bounds(e0=90,e1=30,c0=90,c1=30).
No relapses between baseline and confirmation (high-specificity definition from [1]):
relapse_indep_from_bounds(p0=0,p1=NULL,e0=NULL,e1=NULL,c0=NULL,c1=0).
No relapses from baseline to 30dd after the event, and within confirmation+-30dd [2]:
relapse_indep_from_bounds(p0=0,p1=NULL,e0=NULL,e1=30,c0=30,c1=30).
A named list to be given as argument relapse_indep to function MSprog().
[1] Müller J, Cagol A, Lorscheider J, Tsagkas C, Benkert P, Yaldizli Ö, et al.
Harmonizing definitions for progression independent of relapse activity in multiple sclerosis: A systematic review.
JAMA Neurol. 2023;80:1232–45.
[2] Kappos L, Wolinsky JS, Giovannoni G, Arnold DL, Wang Q, Bernasconi C, et al.
Contribution of relapse-independent progression vs relapse-associated worsening to overall confirmed disability
accumulation in typical relapsing multiple sclerosis in a pooled analysis of 2 randomized clinical trials.
JAMA Neurol. 2020;77:1132–40.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.