| toydata_relapses | R Documentation |
Artificially generated relapse onset dates for some example patients in toydata_visits to illustrate the use of the package.
data(toydata_relapses)
An object of class data.frame, with columns:
Subject IDs.
Relapse onset dates.
This data set was artificially created for the msprog package.
data(toydata_relapses)
head(toydata_relapses)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.