| toydata_visits | R Documentation |
Artificially generated toy data set including Extended Disability Status Scale (EDSS) and Symbol Digit Modalities Test (SDMT) scores in a small cohort of example patients to illustrate the use of the package.
data(toydata_visits)
An object of class data.frame, with columns:
Subject IDs.
Visit dates.
Synthetic EDSS scores (values between 0 and 10).
Synthetic SDMT scores (values between 0 and 110).
This data set was artificially created for the msprog package.
head(toydata_visits)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.